==> com.liferay.layout.content.page.editor.web-1.0.20.jar: META-INF/resources/js/components/sidebar/FragmentsEditorSidebarContent.es.js <==
"use strict";

Liferay.Loader.define("layout-content-page-editor-web@1.0.20/js/components/sidebar/FragmentsEditorSidebarContent.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', './fragments/SidebarElementsPanel.es', './fragments/SidebarSectionsPanel.es', './layouts/SidebarLayoutsPanel.es', './mapping/SidebarMappingPanel.es', './page_structure/SidebarPageStructurePanel.es', './widgets/SidebarWidgetsPanel.es', '../../store/ConnectedComponent.es', '../../actions/actions.es', '../../utils/FragmentsEditorUpdateUtils.es', './FragmentsEditorSidebarContent.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = exports.FragmentsEditorSidebarContent = exports.ConnectedFragmentsEditorSidebarContent = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  require("./fragments/SidebarElementsPanel.es");

  require("./fragments/SidebarSectionsPanel.es");

  require("./layouts/SidebarLayoutsPanel.es");

  require("./mapping/SidebarMappingPanel.es");

  require("./page_structure/SidebarPageStructurePanel.es");

  require("./widgets/SidebarWidgetsPanel.es");

  var _ConnectedComponent = require("../../store/ConnectedComponent.es");

  var _actions = require("../../actions/actions.es");

  var _FragmentsEditorUpdateUtils = require("../../utils/FragmentsEditorUpdateUtils.es");

  var _FragmentsEditorSidebarContent = _interopRequireDefault(require("./FragmentsEditorSidebarContent.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * FragmentsEditorSidebarContent
   * @review
   */
  var FragmentsEditorSidebarContent =
  /*#__PURE__*/
  function (_Component) {
    _inherits(FragmentsEditorSidebarContent, _Component);

    function FragmentsEditorSidebarContent() {
      _classCallCheck(this, FragmentsEditorSidebarContent);

      return _possibleConstructorReturn(this, _getPrototypeOf(FragmentsEditorSidebarContent).apply(this, arguments));
    }

    _createClass(FragmentsEditorSidebarContent, [{
      key: "prepareStateForRender",

      /**
       * @inheritdoc
       * @param {object} state
       * @review
       */
      value: function prepareStateForRender(state) {
        var nextState = state;

        if (state.selectedSidebarPanelId && state.sidebarPanels) {
          var selectedSidebarPanel = state.sidebarPanels.find(function (sidebarPanel) {
            return sidebarPanel.sidebarPanelId === state.selectedSidebarPanelId;
          });

          if (selectedSidebarPanel) {
            nextState = (0, _FragmentsEditorUpdateUtils.setIn)(nextState, ['_selectedSidebarPanel'], selectedSidebarPanel);
          }
        }

        return nextState;
      }
      /**
       * Opens look and feel configuration window
       * @param {!MouseEvent} event
       * @private
       * @review
       */

    }, {
      key: "_handleLookAndFeeldButtonClick",
      value: function _handleLookAndFeeldButtonClick(event) {
        Liferay.Util.navigate(this.lookAndFeelURL);
      }
      /**
       * Updates active panel
       * @param {!MouseEvent} event
       * @private
       * @review
       */

    }, {
      key: "_handlePanelButtonClick",
      value: function _handlePanelButtonClick(event) {
        var sidebarPanelId = event.delegateTarget.dataset.sidebarPanelId;

        if (this.selectedSidebarPanelId === sidebarPanelId) {
          this.store.dispatch({
            sidebarPanelId: '',
            type: _actions.UPDATE_SELECTED_SIDEBAR_PANEL_ID
          });
        } else {
          this.store.dispatch({
            sidebarPanelId: sidebarPanelId,
            type: _actions.UPDATE_SELECTED_SIDEBAR_PANEL_ID
          });
        }
      }
      /**
       * Hides sidebar
       * @private
       * @review
       */

    }, {
      key: "_hideSidebar",
      value: function _hideSidebar() {
        this.store.dispatch({
          sidebarPanelId: '',
          type: _actions.UPDATE_SELECTED_SIDEBAR_PANEL_ID
        });
      }
    }]);

    return FragmentsEditorSidebarContent;
  }(_metalComponent.default);

  exports.FragmentsEditorSidebarContent = FragmentsEditorSidebarContent;
  var ConnectedFragmentsEditorSidebarContent = (0, _ConnectedComponent.getConnectedComponent)(FragmentsEditorSidebarContent, ['lookAndFeelURL', 'selectedSidebarPanelId', 'sidebarPanels', 'spritemap']);
  exports.ConnectedFragmentsEditorSidebarContent = ConnectedFragmentsEditorSidebarContent;

  _metalSoy.default.register(ConnectedFragmentsEditorSidebarContent, _FragmentsEditorSidebarContent.default);

  var _default = ConnectedFragmentsEditorSidebarContent;
  exports.default = _default;
  //# sourceMappingURL=FragmentsEditorSidebarContent.es.js.map
});
//# sourceMappingURL=FragmentsEditorSidebarContent.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/components/sidebar/FragmentsEditorSidebarContent.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/components/sidebar/FragmentsEditorSidebarContent.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', './comments/SidebarCommentsPanel.es', './fragments/SidebarElementsPanel.es', './fragments/SidebarSectionsPanel.es', './layouts/SidebarLayoutsPanel.es', './mapping/SidebarMappingPanel.es', './page_content/SidebarPageContentsPanel.es', './page_structure/SidebarPageStructurePanel.es', './widgets/SidebarWidgetsPanel.es', '../../actions/actions.es', '../../store/ConnectedComponent.es', '../../utils/FragmentsEditorUpdateUtils.es', './FragmentsEditorSidebarContent.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.FragmentsEditorSidebarContent = exports.ConnectedFragmentsEditorSidebarContent = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  require("./comments/SidebarCommentsPanel.es");

  require("./fragments/SidebarElementsPanel.es");

  require("./fragments/SidebarSectionsPanel.es");

  require("./layouts/SidebarLayoutsPanel.es");

  require("./mapping/SidebarMappingPanel.es");

  require("./page_content/SidebarPageContentsPanel.es");

  require("./page_structure/SidebarPageStructurePanel.es");

  require("./widgets/SidebarWidgetsPanel.es");

  var _actions = require("../../actions/actions.es");

  var _ConnectedComponent = require("../../store/ConnectedComponent.es");

  var _FragmentsEditorUpdateUtils = require("../../utils/FragmentsEditorUpdateUtils.es");

  var _FragmentsEditorSidebarContent = _interopRequireDefault(require("./FragmentsEditorSidebarContent.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * FragmentsEditorSidebarContent
   * @review
   */
  var FragmentsEditorSidebarContent =
  /*#__PURE__*/
  function (_Component) {
    _inherits(FragmentsEditorSidebarContent, _Component);

    function FragmentsEditorSidebarContent() {
      _classCallCheck(this, FragmentsEditorSidebarContent);

      return _possibleConstructorReturn(this, _getPrototypeOf(FragmentsEditorSidebarContent).apply(this, arguments));
    }

    _createClass(FragmentsEditorSidebarContent, [{
      key: "prepareStateForRender",

      /**
       * @inheritdoc
       * @param {object} state
       * @review
       */
      value: function prepareStateForRender(state) {
        var nextState = state;

        if (state.selectedSidebarPanelId && state.sidebarPanels) {
          var selectedSidebarPanel = state.sidebarPanels.find(function (sidebarPanel) {
            return sidebarPanel.sidebarPanelId === state.selectedSidebarPanelId;
          });

          if (selectedSidebarPanel) {
            nextState = (0, _FragmentsEditorUpdateUtils.setIn)(nextState, ['_selectedSidebarPanel'], selectedSidebarPanel);
          }
        }

        return nextState;
      }
      /**
       * Opens look and feel configuration window
       * @private
       * @review
       */

    }, {
      key: "_handleLookAndFeeldButtonClick",
      value: function _handleLookAndFeeldButtonClick() {
        Liferay.Util.navigate(this.lookAndFeelURL);
      }
      /**
       * Updates active panel
       * @param {!MouseEvent} event
       * @private
       * @review
       */

    }, {
      key: "_handlePanelButtonClick",
      value: function _handlePanelButtonClick(event) {
        var sidebarPanelId = event.delegateTarget.dataset.sidebarPanelId;

        if (this.selectedSidebarPanelId === sidebarPanelId) {
          sidebarPanelId = '';
        }

        this.store.dispatch({
          type: _actions.UPDATE_SELECTED_SIDEBAR_PANEL_ID,
          value: sidebarPanelId
        });
      }
      /**
       * Hides sidebar
       * @private
       * @review
       */

    }, {
      key: "_hideSidebar",
      value: function _hideSidebar() {
        this.store.dispatch({
          type: _actions.UPDATE_SELECTED_SIDEBAR_PANEL_ID,
          value: ''
        });
      }
    }]);

    return FragmentsEditorSidebarContent;
  }(_metalComponent["default"]);

  exports.FragmentsEditorSidebarContent = FragmentsEditorSidebarContent;
  var ConnectedFragmentsEditorSidebarContent = (0, _ConnectedComponent.getConnectedComponent)(FragmentsEditorSidebarContent, ['lookAndFeelURL', 'selectedSidebarPanelId', 'sidebarPanels', 'spritemap']);
  exports.ConnectedFragmentsEditorSidebarContent = ConnectedFragmentsEditorSidebarContent;

  _metalSoy["default"].register(ConnectedFragmentsEditorSidebarContent, _FragmentsEditorSidebarContent["default"]);

  var _default = ConnectedFragmentsEditorSidebarContent;
  exports["default"] = _default;
  //# sourceMappingURL=FragmentsEditorSidebarContent.es.js.map
});
//# sourceMappingURL=FragmentsEditorSidebarContent.es.js.map
